/************************************************************************
 This Gauss program plots ach probabilities
 Michael Davis and James D. Hamilton
 "The Dynamics of Wholesale Gasoline Prices"
************************************************************************/

output file = junk reset;
library pgraph,optmum;
graphset; optset;   
format 16,8;

meandur1 =        3.5930932 ;
let b1[6,1] =
    1.9455011      -0.11795665        1.5902750     -0.044643274       0.12037017       0.26685961  ;
meandur2 =              2.23205128 ;
let b2[6,1] =
    1.00086341      -0.05798408       0.80775239      -0.00020819       0.01798823       0.89149354 ;
meandur4 =              1.69240669 ;
let b4[6,1] =
       0.96115434      -0.06511580       1.00816529      -0.02739212      -0.06776978    0  ;
meandur7 = 2.77585307;
let b7[6,1] =
     2.78691845      -0.16090066       1.97026965      -0.02832044     
 -0.05327197       0.34699551 ;
meandur11 =       2.29943023 ;
let b11[6,1] = 
 0.51907581      -0.06100256       0.31439567      -0.03111334       0.10063359       0.75029442  ;
meandur12 =       2.41949615 ;
let b12[6,1] =
  2.33239396      -0.18696128       1.15970545      -0.03436162       0.01935470       0.78121583 ;

meandur13 =       2.25257857 ;
let b13[6,1] = 
     1.37102414      -0.07205808       1.49041670      -0.04957481       0.01221341       0.73277191 ;

meandur15 =             2.21963824 ;
let b15[6,1] =
    2.05322198      -0.07701814       1.79542486      -0.03279153      -0.04566270       0.78633603 ;

meandur16 =       2.71556491 ;
let b16[6,1] = 
    1.93414082      -0.12941793       1.41176534      -0.04739084       0.11381917       0.00368237   ;


ntries = 400;
 
x0 = seqa(-20, .1, ntries);

posconst = x0 .>= zeros(ntries,1);
negconst = x0 .< zeros(ntries,1);
posgap = x0 .* posconst;
neggap = -x0 .* negconst;
z0 = posconst ~ posgap ~ negconst ~ neggap;

proc achprobs(bee,meandur);
	local zee,q0;
	q0 = bee[5,1]*meandur/(1 - bee[6,1]);
	zee = z0*bee[1:4,1] + q0 + 1;
	zee = maxc(zee'|ones(1,ntries)); 
	zee = ones(ntries,1) ./ zee;
retp(zee);
endp;

z1 = achprobs(b1,meandur1);
z2 = achprobs(b2,meandur2);
z4 = achprobs(b4,meandur4);
z7 = achprobs(b7,meandur7);
z11 = achprobs(b11,meandur11);
z12 = achprobs(b12,meandur12);
z13 = achprobs(b13,meandur13);
z15 = achprobs(b15,meandur15);
z16 = achprobs(b16,meandur16);


begwind;

graphset;
xsize = (7.5/3) - .25;
ysize = (6/3) - .25;
makewind(xsize,ysize,1,1+2*ysize,1);
makewind(xsize,ysize,1+xsize,1+2*ysize,1);
makewind(xsize,ysize,1+2*xsize,1+2*ysize,1);

makewind(xsize,ysize,1,1+ysize,1);
makewind(xsize,ysize,1+xsize,1+ysize,1);
makewind(xsize,ysize,1+2*xsize,1+ysize,1);


makewind(xsize,ysize,1,1,1);
makewind(xsize,ysize,1+xsize,1,1);
makewind(xsize,ysize,1+2*xsize,1,1);

_pmsgstr =
"Figure 2: Probability of a Price Change (ACH Estimates)";
 _pmsgctl = (5.25~7.2~.5~0~2~15~5); 


axhght = 0.3;
titht = .35;
axht = .35;


setwind(1);
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 1");
xy(x0, z1);

setwind(2);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 2");
xy(x0, z2);

setwind(3);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 3");
xy(x0, z4);

setwind(4);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 4");
xy(x0, z7);

setwind(5);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 5");
xy(x0, z11);

setwind(6);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 6");
xy(x0, z12);

setwind(7);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 7");
xy(x0, z13);

setwind(8);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 8");
xy(x0, z15);

setwind(9);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 9");
xy(x0, z16);







endwind;
