/************************************************************************
 This Gauss program compares alternative ACH models 
 Michael Davis and James D. Hamilton
 "The Dynamics of Wholesale Gasoline Prices"
************************************************************************/

output file = junk reset;
library pgraph,optmum;
graphset; optset;   
format 16,8;

philcont =12;
#include ..\data\readdata.g;  @ reads in data @

/*******************************************************************************************
	set model to be analyzed
*******************************************************************************************/

kbet = 1;
    @ kbet = 0 restricts beta to be zero, kbet = 1 allows estimation @
kthet = 1;
    @ kthet = 0 restricts theta to be zero, kthet = 1 allows estimation @
kneg = 1;
    @ kneg = 1 restricts theta to be positive, kneg = 2 allows positive or negative@

if philcont == 4;
    kneg = 2;
elseif philcont == 7;
    kneg = 2;
elseif philcont == 15;
    kneg = 2;
endif;

t0 = 1;
t1 = nobs;
z = ones(t1,1) ~ absgapc;

/**********************************************************************************************
	set control parameters
*********************************************************************************************/
kz = 	cols(z);          @ kz is the number of explanatory variables, including constant term @
meandur = meanc(duration[t0:t1,1]);
dellit = 	0.1;              @ dellit is smoothness parameter for transition between m(z) = 0 and
                                    m(z) = z @
delsmall = 0.0001;      @ delsmall is the value of el(0) in equation (13) @
kc = 		1;                @ use kc = 2 to print values when likelihood called
                                    kc = 1 for no print @
kqopt = 	1;	          @ use kqopt = 1 for numerical search to avoid crash
                                    use kqopt = 2 for calculation of final standard errors @

kinit = 	0;                @ use kinit = 1 to estimate initial condition
                                    use kinit = 0 to constrain it to the average @                                            
q = 		meandur*ones(capt,1);    @ will be filled in with values of q when proc is called @
h = 		0;                @ will be filled in with values of hazards when proc is called @

#include achin.g;
#include ach2001.g;

/************************************************************************************
	set initial values for parameters 
************************************************************************************/
th0 = 	zeros(kz,1);
th0[1,1] =3;
if kz > 1;
	th0[2,1] = -0.1;
endif;

if kthet > 0;
    th0 = th0 | sqrt(0.1);
endif;
if kbet > 0;
    th0 = th0 | 1;
endif;
if kinit > 0;
     th0 = th0 | sqrt(meandur);
endif;

@ following code is necessary to assure global max is found with some versions of 
   Gauss @
   
if philcont == 4;
    let th0[4,1] = 0.8326   -0.0339   0.0000     0.8980  ;
elseif philcont == 12;
    let th0[4,1] = 0.5 -0.05 0.16 4.5;
elseif philcont == 15;
	let th0[4,1] =        1.6177068     -0.051666494  0.1  0.1;
endif;

kth = rows(th0);     @ kth is the number of parameters @

proc startval;     @ This defines starting value for iteration to be th0 @
  retp(th0); endp;

hout = zeros(4,1);
    @ first element = log like for basic ach
        second element = value when dtrend2 is added
        third element = value when dtlrc is added
	fourth element = value when neg dummy and neg coeff added @


/**********************************************************************************************
 estimate parameters by maximum likelihood 
**********************************************************************************************/
"";"------------------------";"";
kc = 1;

     #include optmum.ext;
      _opalgr = 2;    @ This chooses BFGS optimization  @
      _opmiter = 300;  @ This controls the maximum number of iterations @


@ first estimate ach with only  constant and absgapc as explanatory variables @
z = ones(nobs,1) ~ absgapc;
{thx,f,g,h} =optmum(&ach2001,startval);
thx0 = thx;
hout[1,1] = -f;
thx0[rows(thx0),1] = thx0[rows(thx0),1] + .1;    @ this line prevents bogged down 
                                                    from zero estimated parameter @



@ now estimate ach with constant, absgapc and dtrend2 @
z = ones(nobs,1) ~ absgapc ~  abs(gapc2);
th0 = thx0[1:2,1] | 0 | thx0[3:4,1];
kz = 3;
{thx,f,g,h} =optmum(&ach2001,startval);
hout[2,1] = -f;
hout[2,1] = 2*(hout[2,1] - hout[1,1]);

@ now estimate with constant, absgapc, and dtlrc @
z = ones(nobs,1) ~ absgapc ~ abslastgap;
th0 = thx0[1:2,1] | 0 | thx0[3:4,1];
{thx,f,g,h} =optmum(&ach2001,startval);
hout[3,1] = -f;
hout[3,1] = 2*(hout[3,1] - hout[1,1]);

@ now estimate with constant, gapc, negdummy, and negdummy*gapc @
z = ones(nobs,1) ~ gapc ~ negtrend ~ ntrinter;
th0 = thx0[1:2,1] | 0 | -2*thx0[2,1] | thx0[3:4,1];
kz = 4;

@ perturb starting values for some cases to get to true global max @
if philcont == 7;
    th0[5,1] = -0.05;
    th0[6,1] = 0.7;

elseif philcont == 12;  
    th0[6,1] = 2;
endif;
{thx,f,g,h} =optmum(&ach2001,startval);
hout[4,1] = -f;
hout[4,1] = 2*(hout[4,1] - hout[1,1]);

philcont;;
hout';

