/************************************************************************
 This Gauss program estimates ACH model 
with no constant term or exogenous variables
 Michael Davis and James D. Hamilton
 "The Dynamics of Wholesale Gasoline Prices"
************************************************************************/

output file = junk reset;
library pgraph,optmum;
graphset; optset;   
format 16,8;

philcont = 13;
#include ..\data\readdata.g;  @ reads in data @

/*******************************************************************************************
	set model to be analyzed
*******************************************************************************************/

kbet = 1;
kthet = 1;
t0 = 1;
t1 = nobs;

/**********************************************************************************************
	set control parameters
*********************************************************************************************/
kz = 	0;          @ kz is the number of explanatory variables, including constant term @
kcorr = 1;       @  kcorr = 1 means use ACH(1,1) model
			    kcorr =2 means use ACH(1,0) model with constant term
			    and no correction for sign @
meandur = meanc(duration[t0:t1,1]);
dellit = 	0.1;              @ dellit is smoothness parameter for transition between m(z) = 0 and
                                    m(z) = z @
delsmall = 0.0001;      @ delsmall is the value of el(0) in equation (13) @
kc = 		1;                @ use kc = 2 to print values when likelihood called
                                    kc = 1 for no print @
kqopt = 	1;	          @ use kqopt = 1 for numerical search to avoid crash
                                    use kqopt = 2 for calculation of final standard errors @

kinit = 	0;                @ use kinit = 1 to estimate initial condition
                                    use kinit = 0 to constrain it to the average @                                            
q = 		meandur*ones(nobs,1);    @ will be filled in with values of q when proc is called @
h = 		0;                @ will be filled in with values of hazards when proc is called @

#include achinoex.g;
#include achnoex.g;

/************************************************************************************
	set initial values for parameters 
************************************************************************************/

    th0 = 1 | 2;
   

kth = rows(th0);     @ kth is the number of parameters @

proc startval;     @ This defines starting value for iteration to be th0 @
  retp(th0); endp;



/**********************************************************************************************
 estimate parameters by maximum likelihood 
**********************************************************************************************/
"";"------------------------";"";
kc = 1;

     #include optmum.ext;
      _opalgr = 2;    @ This chooses BFGS optimization  @
      _opmiter = 300;  @ This controls the maximum number of iterations @

       {thx,f,g,h} =optmum(&achnoex,startval);
kqopt = 2;
if kthet > 0;
     thx[kz+1,1] = thx[kz+1,1]^2;
endif;
if kbet > 0;
    thx[kz+kthet+1,1] = thx[kz+kthet+1,1]^2/(1+thx[kz+kthet+1,1]^2);
endif;
if kinit > 0;
     thx[kz+kthet+kbet+1,1] = thx[kz+kthet+kbet+1,1]^2;
endif;
"";"";"Final results";"MLE as parameterized for numerical optimization ";
"Coefficients:";thx';
"";"Value of log likelihood:";;-f;
"";"Gradient vector:";g';

"==================================";
kc = 1;
call achnoex(thx);


/* ------------------------------------------------------------------------------------------------------------------------
   === CALCULATE STANDARD ERRORS === */

kc = 1;
g = gradp(&achnoex,thx);
"";"Numerically calculated gradient:";g;
"";"";
hs = (hessp(&achnoex,thx));
   va = eigrs(hs);
   if minc(eigrs(hs)) <= 0;
        "Negative of Hessian is not positive definite";
        "Either you have not found local maximum, or else estimates are up "
        "against boundary condition.  In latter case, impose the restricted "
        "params rather than estimate them to calculate standard errors";
    else;
       hs = invpd(hs);
       std = diag(hs)^.5;
       "For vector of coefficients parameterized as follows,";(thx)';
       "the standard errors are";std';
    endif;
"variance covariance matrix is";
format /m3;
hs;
format /m1;
hs;

"firm number";;philcont;

/*
"Constant   Dtrend1   Alpha   Beta   Log L   Obs   Vars   SBC";
thx';;
-f;;
nobs;;
rows(thx);;
mz = -f - (rows(thx)/2)*ln(nobs);
mz;
"negative of standard errors";
-std';
*/

