/************************************************************************
 This Gauss program estimates ACH model 
with only a constant term and with beta = 0
 Michael Davis and James D. Hamilton
 "The Dynamics of Wholesale Gasoline Prices"
************************************************************************/

output file = junk reset;
library pgraph,optmum;
graphset; optset;   
format 16,8;

philcont = 13;
#include ..\data\readdata.g;  @ reads in data @

/*******************************************************************************************
	set model to be analyzed
*******************************************************************************************/

kneg = 2;    @ use kneg = 1 to restrict alpha to be non-negative,
		       kneg = 2 to allow to be negative @
if philcont == 13;
	kneg = 1;
endif; 

kbet = 0;
@ kbet = 0;   use to restrict firm 4 asymmetric estimations @

kthet = 1;
t0 = 1;
t1 = nobs;
z = ones(t1-t0+1,1);


/**********************************************************************************************
	set control parameters
*********************************************************************************************/
kz = 	cols(z);          @ kz is the number of explanatory variables, including constant term @
meandur = meanc(duration[t0:t1,1]);
dellit = 	0.1;              @ dellit is smoothness parameter for transition between m(z) = 0 and
                                    m(z) = z @
delsmall = 0.0001;      @ delsmall is the value of el(0) in equation (13) @
kc = 		1;                @ use kc = 2 to print values when likelihood called
                                    kc = 1 for no print @
kqopt = 	1;	          @ use kqopt = 1 for numerical search to avoid crash
                                    use kqopt = 2 for calculation of final standard errors @

kinit = 	0;                @ use kinit = 1 to estimate initial condition
                                    use kinit = 0 to constrain it to the average @                                            
q = 		meandur*ones(capt,1);    @ will be filled in with values of q when proc is called @
h = 		0;                @ will be filled in with values of hazards when proc is called @

#include achin.g;
#include ach2001.g;

/************************************************************************************
	set initial values for parameters 
************************************************************************************/
th0 = 	zeros(kz,1);
th0[1,1] =3;
if kz > 1;
	th0[2,1] = -0.1;
endif;

if kthet > 0;
    th0 = th0 | sqrt(0.1);
endif;
if kbet > 0;
    th0 = th0 | 1;
endif;
if kinit > 0;
     th0 = th0 | sqrt(meandur);
endif;

kth = rows(th0);     @ kth is the number of parameters @

proc startval;     @ This defines starting value for iteration to be th0 @
  retp(th0); endp;

"Initial values";
ach2001(th0);


/**********************************************************************************************
 estimate parameters by maximum likelihood 
**********************************************************************************************/
"";"------------------------";"";
kc = 1;

     #include optmum.ext;
      _opalgr = 2;    @ This chooses BFGS optimization  @
      _opmiter = 300;  @ This controls the maximum number of iterations @

       {thx,f,g,h} =optmum(&ach2001,startval);
kqopt = 2;
if kthet > 0;
	if kneg < 2;
	     thx[kz+1,1] = thx[kz+1,1]^2;
	endif;
endif;
if kbet > 0;
    thx[kz+kthet+1,1] = thx[kz+kthet+1,1]^2/(1+thx[kz+kthet+1,1]^2);
endif;
if kinit > 0;
     thx[kz+kthet+kbet+1,1] = thx[kz+kthet+kbet+1,1]^2;
endif;
"";"";"Final results";"MLE as parameterized for numerical optimization ";
"Coefficients:";thx';
"";"Value of log likelihood:";;-f;
"";"Gradient vector:";g';

"==================================";
kc = 1;
call ach2001(thx);


/* ------------------------------------------------------------------------------------------------------------------------
   === CALCULATE STANDARD ERRORS === */

kc = 1;
g = gradp(&ach2001,thx);
"";"Numerically calculated gradient:";g;
"";"";
hs = (hessp(&ach2001,thx));
   va = eigrs(hs);
   if minc(eigrs(hs)) <= 0;
        "Negative of Hessian is not positive definite";
        "Either you have not found local maximum, or else estimates are up "
        "against boundary condition.  In latter case, impose the restricted "
        "params rather than estimate them to calculate standard errors";
    else;
       hs = invpd(hs);
       std = diag(hs)^.5;
       "For vector of coefficients parameterized as follows,";(thx)';
       "the standard errors are";std';
    endif;
"variance covariance matrix is";
format /m3;
hs;
format /m1;
hs;

"firm number";;philcont;

"Constant   Dtrend1   Alpha   Beta   Log L   Obs   Vars   SBC";
thx';;
-f;;
nobs;;
rows(thx);;
mz = -f - (rows(thx)/2)*ln(nobs);
mz;
"negative of standard errors";
-std';


