/************************************************************************
 This Gauss program compares log likelihood for assorted logistic models
 Michael Davis and James D. Hamilton
 "The Dynamics of Wholesale Gasoline Prices"
************************************************************************/

output file = junk reset;
library pgraph,optmum;
graphset; optset;   
format 16,8;

philcont = 13;
#include ..\data\readdata.g;  @ reads in data @

/*******************************************************************************************
	set model to be analyzed
*******************************************************************************************/

t0 = 1;
t1 = nobs;
z = 0;  th0 = 0;  @ used to avoid tripping error when loading procs @


/**********************************************************************************************
	set control parameters
*********************************************************************************************/
kc = 		1;                @ use kc = 2 to print values when likelihood called
                                    kc = 1 for no print @
h = 		0;                @ will be filled in with values of hazards when proc is called @

#include logit.g;

/************************************************************************************
	set initial values for parameters 
************************************************************************************/

kth = rows(th0);     @ kth is the number of parameters @

proc startval;     @ This defines starting value for iteration to be th0 @
  retp(th0); endp;

hout = zeros(4,1);
    @ first element = log like for basic logit
        second element = value when dtrend2 is added
        third element = value when dtlrc is added
	fourth element = value when neg dummy and neg coeff added @

/**********************************************************************************************
 estimate parameters by maximum likelihood 
**********************************************************************************************/
kc = 1;

     #include optmum.ext;
      _opalgr = 2;    @ This chooses BFGS optimization  @
      _opmiter = 300;  @ This controls the maximum number of iterations @

@ first estimate logit with only  constant and absgapc as explanatory variables @
z = ones(nobs,1) ~ absgapc;
th0 = 1 | -0.1;
{thx,f,g,h} =optmum(&logit2001,startval);
thx0 = thx;
hout[1,1] = -f;

@ now estimate logit with constant, absgapc and dtrend2 @
z = ones(nobs,1) ~ absgapc ~  abs(gapc2);
th0 = thx0 | 0;
{thx,f,g,h} =optmum(&logit2001,startval);
hout[2,1] = -f;
hout[2,1] = 2*(hout[2,1] - hout[1,1]);

@ now estimate with constant, absgapc, and dtlrc @
z = ones(nobs,1) ~ absgapc ~ abslastgap;
th0 = thx0 | 0;
{thx,f,g,h} =optmum(&logit2001,startval);
hout[3,1] = -f;
hout[3,1] = 2*(hout[3,1] - hout[1,1]);

@ now estimate with constant, gapc, negdummy, and negdummy*gapc @
z = ones(nobs,1) ~ gapc ~ negtrend ~ ntrinter;
th0 = thx0 | 0 | -thx0[2,1];
{thx,f,g,h} =optmum(&logit2001,startval);
hout[4,1] = -f;
hout[4,1] = 2*(hout[4,1] - hout[1,1]);

philcont;;
hout';
