/************************************************************************
 This Gauss program estimates logit model 
 Michael Davis and James D. Hamilton
 "The Dynamics of Wholesale Gasoline Prices"
************************************************************************/

output file = junk reset;
library pgraph,optmum;
graphset; optset;   
format 16,8;

philcont = 4;
#include ..\data\readdata.g;  @ reads in data @

/*******************************************************************************************
	set model to be analyzed
*******************************************************************************************/

t0 = 1;
t1 = nobs;
z = posconst ~ posgap ~ negconst ~ neggap;

/**********************************************************************************************
	set control parameters
*********************************************************************************************/
kc = 		1;                @ use kc = 2 to print values when likelihood called
                                    kc = 1 for no print @
h = 		0;                @ will be filled in with values of hazards when proc is called @

#include logit.g;

/************************************************************************************
	set initial values for parameters 
************************************************************************************/
th0 = 1 | -0.1 | 1 | -0.1 ;
kth = rows(th0);     @ kth is the number of parameters @

proc startval;     @ This defines starting value for iteration to be th0 @
  retp(th0); endp;

"Initial values";
logit2001(th0);


/**********************************************************************************************
 estimate parameters by maximum likelihood 
**********************************************************************************************/
"";"------------------------";"";
kc = 1;

     #include optmum.ext;
      _opalgr = 2;    @ This chooses BFGS optimization  @
      _opmiter = 300;  @ This controls the maximum number of iterations @

       {thx,f,g,h} =optmum(&logit2001,startval);
"";"";"Final results";
"Coefficients:";thx';
"";"Value of log likelihood:";;-f;
"";"Gradient vector:";g';

"==================================";
kc = 1;
call logit2001(thx);


/* ------------------------------------------------------------------------------------------------------------------------
   === CALCULATE STANDARD ERRORS === */

kc = 1;
g = gradp(&logit2001,thx);
"";"Numerically calculated gradient:";g;
"";"";
hs = (hessp(&logit2001,thx));
   va = eigrs(hs);
   if minc(eigrs(hs)) <= 0;
        "Negative of Hessian is not positive definite";
        "Either you have not found local maximum, or else estimates are up "
        "against boundary condition.  In latter case, impose the restricted "
        "params rather than estimate them to calculate standard errors";
    else;
       hs = invpd(hs);
       std = diag(hs)^.5;
       "Firm ";;philcont;
       "For vector of coefficients parameterized as follows,";(thx)';
       "the standard errors are";std';
    endif;
"variance covariance matrix is";
format /m3;
hs;
format /m1;
hs;
"";
format 4,4;
"Philadelphia wholesaler #";;philcont;
" posconst    posgap    negconst    neggap";;
"Log L   Obs    Vars    SBC";
thx';;
format 5,5;
-f;;
nobs;;
rows(thx);;
mz = -f - (rows(thx)/2)*ln(nobs);
mz;
"negative of standard errors";
format 4,4;
-std';

