/************************************************************************
 This Gauss program plots logit probabilities
 Michael Davis and James D. Hamilton
 "The Dynamics of Wholesale Gasoline Prices"
************************************************************************/

output file = junk reset;
library pgraph,optmum;
graphset; optset;   
format 16,8;

ntries = 400;
b1 =      -1.2338119     |  0.15068506  |    -0.92526562  |    0.060394414 ;
let b2[4,1] =
 -0.62510710       0.16330647      -0.19057713    0.00058517393  ;
let b4[4,1] =     -0.024211719       0.19668060     -0.035635666       0.11192630;
let b7[4,1] = -1.3314771       0.19607694      -0.56003160      0.022801655 ;
let b11[4,1] =  -0.37009435      0.082377616      -0.18072676      0.037868401  ;
let b12[4,1] =  -1.4713904       0.26582965      -0.50678573      0.070436299;
let b13[4,1] = -0.5209	0.1030	-0.5854	0.0666 ;
let b15[4,1] =   -0.67856441       0.13433727      -0.40273671      0.057359943 ;
let b16[4,1] =      -1.1267614       0.17115335      -0.72103449      0.075669547  ;
 
x0 = seqa(-20, .1, ntries);

posconst = x0 .>= zeros(ntries,1);
negconst = x0 .< zeros(ntries,1);
posgap = x0 .* posconst;
neggap = -x0 .* negconst;
z0 = posconst ~ posgap ~ negconst ~ neggap;

z1 = exp(z0*b1) ./ (1 + exp(z0*b1) );
z2 = exp(z0*b2) ./ (1 + exp(z0*b2) );
z4 = exp(z0*b4) ./ (1 + exp(z0*b4) );
z7 = exp(z0*b7) ./ (1 + exp(z0*b7) );
z11 = exp(z0*b11) ./ (1 + exp(z0*b11) );
z12 = exp(z0*b12) ./ (1 + exp(z0*b12) );
z13 = exp(z0*b13) ./ (1 + exp(z0*b13) );
z15 = exp(z0*b15) ./ (1 + exp(z0*b15) );
z16 = exp(z0*b16) ./ (1 + exp(z0*b16) );

begwind;

graphset;
xsize = (7.5/3) - .25;
ysize = (6/3) - .25;
makewind(xsize,ysize,1,1+2*ysize,1);
makewind(xsize,ysize,1+xsize,1+2*ysize,1);
makewind(xsize,ysize,1+2*xsize,1+2*ysize,1);

makewind(xsize,ysize,1,1+ysize,1);
makewind(xsize,ysize,1+xsize,1+ysize,1);
makewind(xsize,ysize,1+2*xsize,1+ysize,1);


makewind(xsize,ysize,1,1,1);
makewind(xsize,ysize,1+xsize,1,1);
makewind(xsize,ysize,1+2*xsize,1,1);

_pmsgstr =
"Figure 1: Probability of a Price Change (Logit Estimates)";
 _pmsgctl = (5.25~7.2~.5~0~2~15~5); 


axhght = 0.3;
titht = .35;
axht = .35;


setwind(1);
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 1");
xy(x0, z1);

setwind(2);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 2");
xy(x0, z2);

setwind(3);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 3");
xy(x0, z4);

setwind(4);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 4");
xy(x0, z7);

setwind(5);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 5");
xy(x0, z11);

setwind(6);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 6");
xy(x0, z12);

setwind(7);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 7");
xy(x0, z13);

setwind(8);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 8");
xy(x0, z15);

setwind(9);
graphset;
_pmcolor = {6,6,6,6,6,6,6,6,15}; 
_ptitlht = titht;
_pnumht = axhght;
_paxht = axht;
xlabel("Price Gap");
ylabel("Probability");
ytics(0,1,0.2,0);
xtics(-20, 20, 10,0);
title("\201Firm 9");
xy(x0, z16);







endwind;
