/************************************************************************
 This Gauss program summarizes moments of simple reduced-form models

  Michael Davis and James D. Hamilton
 "The Dynamics of Wholesale Gasoline Prices"
************************************************************************/

output file = junk reset;
library pgraph,optmum;
graphset; optset;   
format 16,8;

philcont = 1;
#include ..\data\readdata.g;  @ reads in data @

/******************************************************************************
    graph histogram
 ******************************************************************************/
 delp = price[2:nobs,1] - price[1:nobs-1,1];
 delpstar = pstar[2:nobs,1] - pstar[1:nobs-1,1];
 
 qp = delp ~ delpstar ~ gapc[2:nobs,1];
 qp;
 end;
 
@ delp = sortc(delp,1);
 delp;@

 
 breaks = -3 | -1.5 | -0.1 | 0.1 | 1.5 | 3;
 {c,m,freq} = hist(gapc,breaks);
 end;
  
/*******************************************************************************************
	set model to be analyzed
*******************************************************************************************/

t0 = 1;
t1 = nobs;
ksimple = 2;     @ use ksimple = 1 for simple logit, ksimple = 2 for asymmetric @
if ksimple == 1;
	z = ones(nobs,1) ~ absgapc;
else;
	z = posconst ~ posgap ~ negconst ~ neggap;
endif;


"firm id";;philcont;
/********************************************************************************
    test for random walk approximation to nymex data
 ********************************************************************************/
 ll = 0;
 kc = 2;
proc(2) = lsq(yq,x1);
   @ This proc performs an OLS regression of yq on x1 
        and puts value of log likelihood in the global scalar ll @
local b,eps,sigols,sigmle,ss,nq,nlocal;
   nlocal = rows(yq);
  b = invpd(x1'*x1)*x1'*yq;
   eps = yq - x1*b;
  sigols = sumc(eps^2)/(rows(x1)-cols(x1));
   sigmle = sumc(eps^2)/rows(x1);
   ss = sigols*invpd(x1'*x1);
   ll = -(nlocal/2)*(1 + ln(2*pi)) - (nlocal/2)*ln(sigmle);
 if kc > 1;
    ""; "ols coefficients";b';
     "ols see";;sqrt(sigols);
    "mle see";;sqrt(sigmle);
    "standard errors";sqrt(diag(ss))';
    "ols log likelihood";; ll;"";
endif;
retp(b,sigmle^.5);
endp;

y = 100*(ln(pstar[2:nobs,1]) - ln(pstar[1:nobs-1,1]));
nlags = 2;

x = ones(nobs-1-nlags,1);
ilag = 1;
do until ilag > nlags;
    x = x ~ y[nlags+1-ilag:rows(y)-ilag,1];
ilag = ilag + 1;
endo;
y = y[nlags+1:nobs-1,1];
  

 {bhat,sigmle} = lsq(y,x);

"maximum price gap";;maxc(gapc);
"minimum price gap";;minc(gapc);


 
