/************************************************************************
 This Gauss program estimates menu cost model 
 Michael Davis and James D. Hamilton
 "The Dynamics of Wholesale Gasoline Prices"
************************************************************************/

output file = menu16.out reset;
library pgraph,optmum;
graphset; optset;   
format 16,8;

philcont = 15;
#include ..\data\readdata.g;  @ reads in data @

/*******************************************************************************************
	set model to be analyzed
*******************************************************************************************/

t0 = 1;
t1 = rows(event);
z =loggap;

/**********************************************************************************************
	set control parameters
*********************************************************************************************/
kc = 		1;                @ use kc = 2 to print values when likelihood called
                                    kc = 1 for no print @
kqopt = 	1;	          @ use kqopt = 1 for numerical search to avoid crash
                                    use kqopt = 2 for calculation of final standard errors @

h = 		0;                @ will be filled in with values of hazards when proc is called @

#include menuin.g;
#include menu2001.g;

/************************************************************************************
	set initial values for parameters 
************************************************************************************/
th0 = 0.5 | 0.5;
if philcont == 4;
	th0 = 0.22 | 0.3;
endif;
kth = rows(th0);     @ kth is the number of parameters @

proc startval;     @ This defines starting value for iteration to be th0 @
  retp(th0); endp;

"Initial values";
menu2001(th0);


/**********************************************************************************************
 estimate parameters by maximum likelihood 
**********************************************************************************************/
"";"------------------------";"";
kc = 1;

     #include optmum.ext;
      _opalgr = 2;    @ This chooses BFGS optimization  @
      _opmiter = 300;  @ This controls the maximum number of iterations @

       {thx,f,g,h} =optmum(&menu2001,startval);
kqopt = 2;
thx = thx^2;
"";"";"Final results";
"Coefficients:";thx';
"";"Value of log likelihood:";;-f;
"";"Gradient vector:";g';

"==================================";
kc = 1;
call menu2001(thx);


/* ------------------------------------------------------------------------------------------------------------------------
   === CALCULATE STANDARD ERRORS === */

kc = 1;
g = gradp(&menu2001,thx);
"";"Numerically calculated gradient:";g;
"";"";
hs = (hessp(&menu2001,thx));
   va = eigrs(hs);
   if minc(eigrs(hs)) <= 0;
        "Negative of Hessian is not positive definite";
        "Either you have not found local maximum, or else estimates are up "
        "against boundary condition.  In latter case, impose the restricted "
        "params rather than estimate them to calculate standard errors";
    else;
       hs = invpd(hs);
       std = diag(hs)^.5;
       "For vector of coefficients parameterized as follows,";(thx)';
       "the standard errors are";std';
    endif;
"variance covariance matrix is";
format /m3;
hs;
format /m1;
hs;

"Philadelphia wholesaler #";;philcont;
b = thx[1,1];
sig = thx[2,1];
" b          sigma(MLE)                sigma(direct)      g/k      log L      Obs     Vars      SBC";
b;;sig;;
if philcont .ne 13;
	mz = ln (nymex[2:capt,2] ./ nymex[1:capt-1,2] );
	mz = sqrt( meanc(mz^2) );
	mz;;
endif;
mz = (b^4)/(6*sig^2);
mz;;
-f;;
nobs;;
rows(thx);;
mz = -f - (rows(thx)/2)*ln(nobs);
mz;
"negative of standard errors";
-std';

